@@ -103,14 +103,16 @@ class dataset_loader:
         else:
             print("从互联网获取数据集")
             symbols_list = self.__get_symbols_by_wc(self.question, columns=['股票代码'])
-
+            print("开始遍历")
             for index, symbol in enumerate(symbols_list['股票代码'].unique()):
-                print("数据进度百分比:%s" % (index / len(symbols_list['股票代码'].unique()) * 100), end="\r")
+                print("数据进度百分比:%s" % (index / len(symbols_list['股票代码'].unique()) * 100), end='\r', flush=True)
                 # 获取股票代码的符合的年数据
                 # symbol_data = symbols_list[symbols_list['股票代码'] == symbol]
                 # # 获取股票代码的年数据的时间集合
                 # self.symbol_index.update({symbol: num_kit.date_split(symbol_data['trade_date'])})
                 self.data = pd.concat([self.data, self.__daily_data(symbol, self.start, self.end)])
+
+
         # 重置索引
         self.data = self.data.reset_index(drop=True)
         # 将日期转换为字符串
@@ -128,13 +130,16 @@ class dataset_loader:
         mlflow.log_text("data_report", "\n".join(self.__data_report()))
         # 新增数据集
 
-    def save(self, file_path='../data/data.csv'):
+    def save(self, path='../data/', name='data.csv'):
         """
         保存数据集
+        :param name:
         :param path:
         :return:
         """
-        self.data.to_csv(file_path, index=False, encoding='utf-8')
+        if not os.path.exists(path):
+            os.mkdir(path)
+        self.data.to_csv(path+name, index=False, encoding='utf-8',)
 
     def __data_report(self):
         """
@@ -184,12 +189,15 @@ class dataset_feature:
         """
         pass
 
-    def save(self, path='../data/dataset.csv'):
+    def save(self, path='../data/', name='dataset.csv'):
         """
         保存数据集
+        :param name:
         :param path:
         :return:
         """
+        if not os.path.exists(path):
+            os.mkdir(path)
         self.data.to_csv(path, index=False, encoding='utf-8')
 
     def execute(self):
